/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file WordListProxyStyle.cpp
    \brief Custom proxy style that draws checkboxes as stars.

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include "WordListProxyStyle.h"


WordListProxyStyle::WordListProxyStyle() :
    QProxyStyle()
{
    //load pixmap from resources
    #ifdef Q_WS_MAEMO_5
        starPixmapOn = QPixmap(":/icons/96x96/staron.png");
        starPixmapOff = QPixmap(":/icons/96x96/staroff.png");
    #else
        starPixmapOn = QPixmap(":/icons/16x16/staron.png");
        starPixmapOff = QPixmap(":/icons/16x16/staroff.png");
    #endif
}


void WordListProxyStyle::drawPrimitive(PrimitiveElement element,
                                       const QStyleOption *option,
                                       QPainter *painter,
                                       const QWidget *widget) const {
    if(element == PE_IndicatorCheckBox) {
        if(option->state & QStyle::State_On)
            painter->drawPixmap(option->rect, starPixmapOn);
        else
            painter->drawPixmap(option->rect, starPixmapOff);
    }
    else {
        QProxyStyle::drawPrimitive(element, option, painter, widget);
    }
}


