/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/

/*! \file main.cpp
    \brief mDictionary's main file
    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include <QtGui/QApplication>
#include "MainWindow.h"
#include "../backbone/backbone.h"
#include "../../include/translation.h"
#include "../../include/Notify.h"
#include "DBusAdapter.h"
#include <QDebug>
#include <QDBusConnection>



QStringList parseParameters(int argc, char *argv[]) {
    bool wordListStarted = false;
    QStringList result;
    for(int i=1; i<argc; i++) {
        QString argument(argv[i]);
        if(!wordListStarted) {
            if(argument == "-s" || argument == "--search") {
                wordListStarted = true;
            }
        }
        else {
            if(!argument.startsWith("-") &&
               !argument.startsWith("--")) {
                result << argument;
            }
        }
    }

    return result;
}

void retranslate() {
    QString locale = QLocale::system().name();

    QTranslator *translator = new QTranslator;
    QTranslator *qtTranslator = new QTranslator;

    qtTranslator->load("qt_" + locale,
    QLibraryInfo::location(QLibraryInfo::TranslationsPath));
    QCoreApplication::installTranslator(qtTranslator);

    if(!translator->load(":/translations/" + locale)) {
        translator->load(":/translations/en_US");

    }

    QCoreApplication::installTranslator(translator);
}

int main(int argc, char *argv[]) {
    QApplication a(argc, argv);
    QApplication::setOrganizationName("Comarch S.A.");
    QApplication::setOrganizationDomain("comarch.com");
    QApplication::setApplicationName("mDictionary");

    QStringList search = parseParameters(argc, argv);

    qRegisterMetaType<Translation*>("Translation*");
    qRegisterMetaType<QList<Translation*> >("QList<Translation*>");
    qRegisterMetaType<Notify>("Notify");
    qRegisterMetaType<Notify::NotifyType>("Notify::NotifyType");

    retranslate();

    Backbone* backbone = new Backbone();
    MainWindow* mainWindow = new MainWindow(backbone);

    DBusAdapter* adapter = new DBusAdapter(mainWindow);

    QDBusConnection::sessionBus().registerObject("/mainWindow",
                                                 mainWindow);
    QDBusConnection::sessionBus().registerService("com.comarch.mdictionary");

    mainWindow->show();

    if(search.count() > 0) {
        mainWindow->setExactSearch(true);
        mainWindow->searchExact(search[0]);
    }

    int res = a.exec();

    QDBusConnection::sessionBus().unregisterObject("/mainWindow");
    QDBusConnection::sessionBus().unregisterService("com.comarch.mdictionary");

    delete adapter;
    delete mainWindow;
    delete backbone;

    return res;
}
