/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file GoogleDialog.cpp
    \brief Implementation of google plugin's dialogs.

    \author Jakub Jaszczynski <j.j.jaszczynski@gmail.com>
*/

#include "GoogleDialog.h"
#include <QDebug>

GoogleDialog::GoogleDialog(GooglePlugin *plugin,
                           GoogleDialogType type,
                           QWidget *parent) : QDialog(parent) {
    this->plugin = plugin;
    this->type = type;
    _settings = 0;

    if(plugin) {
        _langTo=GooglePlugin::languages.key(
                plugin->settings()->value("lang_to"));

        _langFrom=GooglePlugin::languages.key(
                plugin->settings()->value("lang_from"));
    }
    else {
        _langTo=GooglePlugin::languages.key("pl");
        _langFrom=GooglePlugin::languages.key("en");
    }

    initializeUI();

    connect(confirmButton, SIGNAL(clicked()),
            this, SLOT(accept()));

    connect(langFromComboBox, SIGNAL(currentIndexChanged(int)),
            this, SLOT(langFromChanged(int)));

    connect(langToComboBox, SIGNAL(currentIndexChanged(int)),
            this, SLOT(langToChanged(int)));

    connect(changeLangButton, SIGNAL(clicked()),
            this, SLOT(changeLangButtonClicked()));
}


void GoogleDialog::initializeUI() {
    int i=0,j=0;
    int actualLangTo=0;
    int actualLangFrom=0;

    setWindowTitle(tr("Google Plugin Settings"));

    langFromLabel = new QLabel(tr("From:"));
    langToLabel = new QLabel(tr("To: "));

    verticalLayout = new QVBoxLayout;
    setLayout(verticalLayout);

    langLayout = new QVBoxLayout;
    langsFormLayout = new QFormLayout;
    changeLangLayout = new QHBoxLayout;

    #ifdef Q_WS_MAEMO_5
        setMinimumHeight(370);
        changeLangButton=new QPushButton(
                QIcon::fromTheme("general_refresh"), "");
    #else
        changeLangButton=new QPushButton(
                QIcon::fromTheme("object-flip-vertical"),"");
    #endif

    infoLabel = new QLabel;
    infoLabel->setText(tr("Plugin: GoogleTranslator \n")+
                   tr("From: ") + _langFrom + "\n" +
                   tr("To: ") + _langTo);
    verticalLayout->addWidget(infoLabel);

    #ifdef Q_WS_MAEMO_5
        connectInfoLabel = new QLabel(tr("Google plugin makes use of Internet "
                                         "connection, so it may cost You."));
        connectInfoLabel->setWordWrap(true);
        verticalLayout->addWidget(connectInfoLabel);
    #endif

    langFromComboBox = new QComboBox;
    langToComboBox = new QComboBox;

    foreach(QString langs, GooglePlugin::languages.keys()){
        if(langs==_langTo)
            actualLangTo=j;
        if(langs==_langFrom)
            actualLangFrom=i;
        if(langs!="Detect langlage"){
            langToComboBox->addItem(langs);
            j++;
        }
        langFromComboBox->addItem(langs);
        i++;
    }

    langToComboBox->setCurrentIndex(actualLangTo);
    langFromComboBox->setCurrentIndex(actualLangFrom);

    langLayout->addLayout(langsFormLayout);

    langsFormLayout->addRow(langFromLabel, langFromComboBox);
    langsFormLayout->addRow(langToLabel, langToComboBox);

    changeLangLayout->addLayout(langLayout);
    changeLangLayout->addWidget(changeLangButton);

    verticalLayout->addLayout(changeLangLayout);

    confirmButton = new QPushButton;
    if(type == New) {
        confirmButton->setText(tr("Add"));
    }
    else {
        confirmButton->setText(tr("Save settings"));
    }

    verticalLayout->addWidget(confirmButton);

    setModal(true);
    setMinimumSize(sizeHint());
    setMaximumSize(sizeHint());
}


void GoogleDialog::langFromChanged(int index) {
    _langFrom=langFromComboBox->itemText(index);
}


void GoogleDialog::langToChanged(int index) {
     _langTo=langToComboBox->itemText(index);
}


void GoogleDialog::changeLangButtonClicked() {
    int indexTo=langToComboBox->findText(langFromComboBox->currentText());
    int indexFrom=langFromComboBox->findText(langToComboBox->currentText());

    if(indexTo!= -1 && indexFrom!= -1) {
        langToComboBox->setCurrentIndex(indexTo);
        langFromComboBox->setCurrentIndex(indexFrom);
    }
}


void GoogleDialog::accept() {
    saveSettings();
    QDialog::accept();
}


void GoogleDialog::saveSettings() {
    _settings = new Settings;
    if(plugin) {
        foreach(QString key, plugin->settings()->keys())
            _settings->setValue(key, plugin->settings()->value(key));
    }

    _settings->setValue("lang_to",
                        GooglePlugin::languages.value(_langTo));
    _settings->setValue("lang_from",
                        GooglePlugin::languages.value(_langFrom));
}


Settings* GoogleDialog::getSettings() {
    return _settings;
}
