/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file TranslationStarDict.cpp
    \brief Implementation of stardict plugin's translation.

    \author Jakub Jaszczynski <j.j.jaszczynski@gmail.com>
*/

#include "TranslationStarDict.h"
#include <QDebug>


TranslationStarDict::TranslationStarDict():_key(""),_dictionaryInfo("") {
    starDictPlugin=0;
}


TranslationStarDict::TranslationStarDict(QString _key, QString _dictionaryInfo,
         StarDictPlugin *starDictPlugin): _key(_key),_dictionaryInfo(_dictionaryInfo) {
    this->starDictPlugin=starDictPlugin;
    if(starDictPlugin)
        _dictHash = starDictPlugin->hash();
    _bookmark=0;
}


TranslationStarDict::TranslationStarDict(const TranslationStarDict &base) {
    _key = base.key();
    _dictHash = base._dictHash;
    _dictionaryInfo = base._dictionaryInfo;
    lengths = base.lengths;
    offsets = base.offsets;
    starDictPlugin = base.starDictPlugin;
}


void TranslationStarDict::add(qint64 offset, qint32 len) {
    offsets.append(offset);
    lengths.append(len);
}


QString TranslationStarDict::key() const {
    return _key;
}


QString TranslationStarDict::toXml() const {
    QString result("");
    if(!starDictPlugin)
        return result;

    for(int i = 0; i < offsets.size(); i++) {
        result=result + "<dict> <info path=\"/usr/share/mdictionary/stardict.png\" ";
        if(isBookmark())
            result+= " bookmark=\"true\" > \n";
        else
            result+= " bookmark=\"false\" > \n";
            if(_dictionaryInfo.isEmpty())
                result+= "starDict dictionary </info>";
            else
                result+= _dictionaryInfo +"</info>";

            /*conwert returned string to XML format*/
            result+=starDictPlugin->search(_key, offsets.at(i), lengths.at(i));
            result+= "</dict>";
   }
   return result;
}


void TranslationStarDict::setKey(QString _key) {
    this->_key=_key;
}


void TranslationStarDict::setDictionaryInfo(QString _dictionaryInfo) {
    this->_dictionaryInfo=_dictionaryInfo;
}

