/*******************************************************************************

    This file is part of mDictionary.

    mDictionary is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    mDictionary is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with mDictionary.  If not, see <http://www.gnu.org/licenses/>.

    Copyright 2010 Comarch S.A.

*******************************************************************************/
/*!
    \file XdxfDictDialog.cpp
    \brief Implementation of DictDialog interface for xdxf plugin

    \author Mateusz Półrola <mateusz.polrola@comarch.pl>
*/

#include "XdxfDictDialog.h"
#include "xdxfplugin.h"
#include "XdxfDialog.h"
#include <QDebug>

XdxfDictDialog::XdxfDictDialog(XdxfPlugin *plugin, QObject *parent) :
    DictDialog(parent) {
    this->plugin = plugin;
    _lastDialogParent=0;
}


QWidget* XdxfDictDialog::lastDialogParent() {
    return _lastDialogParent;
}


void XdxfDictDialog::setLastDialogParent(QWidget *w) {
    _lastDialogParent = w;
}


Settings* XdxfDictDialog::addNewDictionary(QWidget *parent) {
    XdxfDialog d(0, XdxfDialog::New, parent);

    setLastDialogParent(parent);

    connect(&d, SIGNAL(notify(Notify::NotifyType,QString)),
            this, SIGNAL(notify(Notify::NotifyType,QString)));

    if(d.exec() == QDialog::Accepted) {
        return d.getSettings();
    }
    return 0;
}

void XdxfDictDialog::changeSettings(QWidget * parent) {
    XdxfDialog d(plugin, XdxfDialog::Change, parent);

    setLastDialogParent(parent);

    connect(&d, SIGNAL(notify(Notify::NotifyType,QString)),
            this, SIGNAL(notify(Notify::NotifyType,QString)));

    if(d.exec() == QDialog::Accepted) {
        plugin->setSettings(d.getSettings());
    }
}
